===
Mai
===

AWS SAML login command line utility.

.. code-block:: bash

    $ sudo pip3 install --upgrade stups-mai

Usage
=====

.. code-block:: bash

    $ mai create my-profile
    $ mai # short for "mai login my-profile"
